@@ -6,8 +6,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef ABOUTDATA_H
-#define ABOUTDATA_H
+#pragma once
 
 #include "kaddressbook_export.h"
 
@@ -27,4 +26,3 @@ public:
     ~AboutData();
 };
 
-#endif /* ABOUTDATA_H */
