@@ -8,11 +8,11 @@
 
 #include "kaddressbook_debug.h"
 
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/item.h>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/Item>
 
-#include <kcontacts/addressee.h>
-#include <kcontacts/contactgroup.h>
+#include <KContacts/Addressee>
+#include <KContacts/ContactGroup>
 
 #include "categoryselectwidget.h"
 
@@ -46,10 +46,7 @@ CategoryFilterProxyModel::CategoryFilterProxyModel(QObject *parent)
     setDynamicSortFilter(true);
 }
 
-CategoryFilterProxyModel::~CategoryFilterProxyModel()
-{
-    delete d_ptr;
-}
+CategoryFilterProxyModel::~CategoryFilterProxyModel() = default;
 
 bool CategoryFilterProxyModel::filterAcceptsRow(int row, const QModelIndex &parent) const
 {
