@@ -10,6 +10,8 @@
 
 #include <KLocalizedString>
 #include <QUrl>
+#include <kcontacts_version.h>
+
 using namespace KAddressBookImportExport;
 
 QString ContactFields::label(Field field)
@@ -163,17 +165,24 @@ void ContactFields::setValue(Field field, const QString &value, KContacts::Addre
     case ContactFields::Anniversary:
         contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Anniversary"), value);
         break;
-    case ContactFields::PreferredEmail:
+    case ContactFields::PreferredEmail: {
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
         contact.insertEmail(value, true);
+#else
+        KContacts::Email email(value);
+        email.setPreferred(true);
+        contact.addEmail(email);
+#endif
         break;
+    }
     case ContactFields::Email2:
-        contact.insertEmail(value, false);
-        break;
     case ContactFields::Email3:
-        contact.insertEmail(value, false);
-        break;
     case ContactFields::Email4:
+#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
         contact.insertEmail(value, false);
+#else
+        contact.addEmail(KContacts::Email(value));
+#endif
         break;
     case ContactFields::Role:
         contact.setRole(value);
