@@ -5,12 +5,11 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef KAddressBookCONTACTSELECTIONWIDGET_H
-#define KAddressBookCONTACTSELECTIONWIDGET_H
+#pragma once
 
 #include "contactlist.h"
 #include "kaddressbook_importexport_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <KContacts/Addressee>
 
 #include <QWidget>
@@ -86,4 +85,3 @@ private:
     bool mAddContactGroup = false;
 };
 }
-#endif
