@@ -20,7 +20,7 @@ ExportSelectionWidget::ExportSelectionWidget(QWidget *parent)
     : QWidget(parent)
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    mainLayout->setContentsMargins({});
     auto gbox = new QGroupBox(i18nc("@title:group", "Fields to be exported"), this);
     mainLayout->addWidget(gbox);
     auto layout = new QGridLayout;
