@@ -15,7 +15,6 @@
 #include "globalcontactmodel.h"
 #include "kaddressbook_options.h"
 #include "kaddressbookadaptor.h"
-#include "kcmutils_version.h"
 #include "manageshowcollectionproperties.h"
 #include "modelcolumnmanager.h"
 #include "printing/printingwizard.h"
@@ -37,17 +36,16 @@
 #include <PimCommonAkonadi/ImapAclAttribute>
 #include <PimCommonAkonadi/MailUtil>
 
-#include <AkonadiCore/AttributeFactory>
-#include <AkonadiCore/CollectionFilterProxyModel>
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#include <AkonadiCore/MimeTypeChecker>
+#include <Akonadi/AttributeFactory>
+#include <Akonadi/CollectionFilterProxyModel>
+#include <Akonadi/CollectionMaintenancePage>
+#include <Akonadi/CollectionPropertiesDialog>
+#include <Akonadi/ControlGui>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityMimeTypeFilterModel>
+#include <Akonadi/EntityTreeView>
+#include <Akonadi/MimeTypeChecker>
 #include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
-#include <AkonadiWidgets/CollectionMaintenancePage>
-#include <AkonadiWidgets/CollectionPropertiesDialog>
-#include <AkonadiWidgets/ControlGui>
-#include <AkonadiWidgets/ETMViewStateSaver>
-#include <AkonadiWidgets/EntityTreeView>
-#include <AkonadiWidgets/ItemView>
 #include <KContacts/Addressee>
 #include <PimCommon/PimUtil>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
@@ -69,7 +67,6 @@
 #include <KContacts/ContactGroup>
 #include <KDescendantsProxyModel>
 #include <KLocalizedString>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <KSelectionProxyModel>
 #include <KToggleAction>
@@ -78,7 +75,7 @@
 #include <QApplication>
 #include <QTextBrowser>
 
-#include <ItemModifyJob>
+#include <Akonadi/ItemModifyJob>
 #include <KPimPrintPreviewDialog>
 #include <QActionGroup>
 #include <QDBusConnection>
@@ -353,13 +350,9 @@ void MainWidget::initializeImportExportPlugin(KActionCollection *collection)
 void MainWidget::configure()
 {
     QPointer<KCMultiDialog> dlg = new KCMultiDialog(this);
-    const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/kaddressbook"));
+    const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/kaddressbook"));
     for (const KPluginMetaData &metaData : availablePlugins) {
-#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
         dlg->addModule(metaData);
-#else
-        dlg->addModule(metaData.pluginId());
-#endif
     }
     dlg->exec();
     delete dlg;
@@ -504,7 +497,7 @@ void MainWidget::setupGui()
 {
     // the horizontal main layout
     auto layout = new QHBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     // Splitter 1 contains the two main parts of the GUI:
     //  - collection and item view splitter 2 on the left (see below)
@@ -545,7 +538,7 @@ void MainWidget::setupGui()
     mMainWidgetSplitter1->setChildrenCollapsible(false);
 
     auto detailsPaneLayout = new QVBoxLayout(mDetailsPane);
-    detailsPaneLayout->setContentsMargins(0, 0, 0, 0);
+    detailsPaneLayout->setContentsMargins({});
 
     // the details view stack
     mDetailsViewStack = new QStackedWidget();
@@ -672,7 +665,7 @@ void MainWidget::setupActions(KActionCollection *collection)
     collection->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_3));
     collection->addAction(QStringLiteral("view_mode_3columns"), act);
 
-    connect(mViewModeGroup, qOverload<QAction *>(&QActionGroup::triggered), this, qOverload<QAction *>(&MainWidget::setViewMode));
+    connect(mViewModeGroup, &QActionGroup::triggered, this, &MainWidget::setActivateViewMode);
 
     KToggleAction *actTheme = mGrantleeThemeManager->actionForTheme();
     if (actTheme) {
@@ -856,7 +849,7 @@ QAbstractItemModel *MainWidget::allContactsModel()
     return mAllContactsModel;
 }
 
-void MainWidget::setViewMode(QAction *action)
+void MainWidget::setActivateViewMode(QAction *action)
 {
     setViewMode(action->data().toInt());
 }
