@@ -6,11 +6,10 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAINWIDGET_H
-#define MAINWIDGET_H
+#pragma once
 
 #include "kaddressbook_export.h"
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 #include <QItemSelection>
 #include <QWidget>
 
@@ -97,7 +96,7 @@ private Q_SLOTS:
     void itemSelectionChanged(const QModelIndex &, const QModelIndex &);
     void selectFirstItem();
 
-    void setViewMode(QAction *action);
+    void setActivateViewMode(QAction *action);
     void setQRCodeShow(bool on);
 
     void restoreState();
@@ -164,4 +163,3 @@ private:
     Akonadi::Item mPendingSelection;
 };
 
-#endif
