@@ -21,7 +21,6 @@
 #include <QAction>
 #include <QMenuBar>
 #include <QPointer>
-#include <kxmlgui_version.h>
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 #include <KUserFeedback/NotificationPopup>
@@ -108,7 +107,7 @@ void MainWindow::configure()
 
 void MainWindow::configureKeyBindings()
 {
-    KShortcutsDialog *dlg = new KShortcutsDialog(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
+    KShortcutsDialog *dlg = new KShortcutsDialog(this);
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setModal(false);
     dlg->addCollection(actionCollection());
