@@ -7,8 +7,8 @@
 
 #include "printprogress.h"
 
-#include <QApplication>
 #include <KLocalizedString>
+#include <QApplication>
 #include <QTextBrowser>
 
 #include <QGridLayout>
@@ -21,7 +21,7 @@ PrintProgress::PrintProgress(QWidget *parent)
 {
     setWindowTitle(i18nc("@title:window", "Printing: Progress"));
 
-    auto *topLayout = new QGridLayout(this);
+    auto topLayout = new QGridLayout(this);
 
     mLogBrowser = new QTextBrowser(this);
     topLayout->addWidget(mLogBrowser, 0, 0);
@@ -41,8 +41,7 @@ void PrintProgress::addMessage(const QString &msg)
 {
     mMessages.append(msg);
 
-    QString head = QLatin1String("<qt><b>") + i18n("Progress")
-                   +QLatin1String(":</b><ul>");
+    QString head = QLatin1String("<qt><b>") + i18n("Progress") + QLatin1String(":</b><ul>");
 
     const QString foot = QStringLiteral("</ul></qt>");
 
