@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef UISTATESAVER_H
-#define UISTATESAVER_H
+#pragma once
 
 #include "kaddressbook_export.h"
 
@@ -50,4 +49,3 @@ KADDRESSBOOK_EXPORT void restoreState(QWidget *widget, const KConfigGroup &confi
 }
 }
 
-#endif
