@@ -14,12 +14,15 @@
 #include <QKeyEvent>
 #include <QTimer>
 #include <QVBoxLayout>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 QuickSearchWidget::QuickSearchWidget(QWidget *parent)
     : QWidget(parent)
 {
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     mEdit = new QLineEdit(this);
     // If change shortcut changes it in mainwidget
@@ -57,7 +60,7 @@ void QuickSearchWidget::slotFocusQuickSearch()
 void QuickSearchWidget::resetTimer()
 {
     mTimer->stop();
-    mTimer->start(500);
+    mTimer->start(500ms);
 }
 
 void QuickSearchWidget::delayedTextChanged()
